<?php
namespace common\models;

use DateTime;
use Yii;
use yii\base\Model;
use yii\db\Exception;
use yii\helpers\ArrayHelper;


/**
 * Login form
 */
class Common extends Model
{
    public static function randomStrings($len)
    {

        // Shuffle the $str_result and returns substring
        // of specified length
        return substr(str_shuffle('0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'), 0, $len);

    }

    public static function generateHashString($password)
    {

        try {

            return Yii::$app->getSecurity()->generatePasswordHash($password);

        } catch (\Exception $e) {

            return null;

        }

    }

    public static function verifyHashString($real_password, $hash_password)
    {

        try {

            if (Yii::$app->getSecurity()->validatePassword($real_password, $hash_password)) {

                return true;

            } else {

                return false;

            }

        } catch (\Exception $e) {

            return false;

        }

    }

    public static function remainingDaysFromNow($targetDate) // Example target date format 2024-03-16
    {
        $now = new DateTime();
        $target = new DateTime($targetDate);
        $interval = $now->diff($target);
        $days = $interval->format('%r%a');

        if( $days > 1 )
        {
            return '<span class="badge bg-success-subtle text-success badge-border"> ' . $days. ' days </span>';
        }elseif ( $days == 1){

            return ' <span class="badge bg-warning-subtle text-warning badge-border"> ' . $days. ' day </span';
        }elseif ($days == 0){

            return ' <span class="badge bg-danger-subtle text-danger badge-border"> ' . abs($days). ' day </span';
        }else{

            return ' <span class="badge bg-dark-subtle text-dark badge-border"> 0 day</span>';
        }
    }

    public static function borrowedStatus( $status )
    {
        //borrow_status
        //10 - New Asset, 20 - Returned, 30 - Borrowed, 40 - Not Allowed to Borrow

        if( $status == 10 )
        {
            return '<span class="badge badge-label bg-info"><i class="mdi mdi-new-box"></i> New Asset </span>';
        }elseif ( $status == 20 )
        {

            return '<span class="badge badge-label bg-success"><i class="mdi mdi-arrow-left"></i> Returned </span>';
        }elseif ( $status == 30 )
        {

            return '<span class="badge badge-label bg-warning"><i class="mdi mdi-arrow-right"></i> Borrowed </span>';
        }elseif ( $status == 40 )
        {

            return '<span class="badge badge-label bg-danger"><i class="mdi mdi-cancel"></i> Not Allowed </span>';
        }else
        {

            return '<span class="badge badge-label bg-dark"><i class="mdi mdi-circle-medium"></i> NaN </span>';
        }
    }

    public static function generateStrongToken()
    {
        $segments = [];
        $segmentLengths = [8, 6, 5, 4, 5, 6, 8]; // Length of each segment

        foreach ($segmentLengths as $length) {
            $segment = bin2hex(random_bytes($length));
            $segments[] = $segment;
        }

        $token = implode('-', $segments);

        return $token;
    }


}
