<?php

namespace common\models;

use frontend\models\Country;
use frontend\models\Events;
use frontend\models\Region;
use frontend\models\Season;
use yii\validators\ImageValidator;

class PostEvent extends Events
{

    public function rules()
    {
        return [
            [['name', 'venue', 'country_id', 'region_id', 'address', 'map', 'start_date', 'start_time', 'end_date', 'end_time', 'sales_close', 'season_id', 'cover'], 'required'],
            [['descriptions', 'map'], 'string'],
            [['country_id', 'region_id', 'currency_id', 'season_id', 'status'], 'integer'],
            [['start_date', 'start_time', 'end_date', 'end_time', 'sales_close', 'created_at', 'updated_at'], 'safe'],
            [['name', 'venue', 'address', 'cover'], 'string', 'max' => 255],
            [['cover'], 'file','extensions' => 'png, jpg, jpeg, gif', 'maxFiles' => 1, 'maxSize' => 2 * 1024 * 1024],
            [['cover'], ImageValidator::class, 'maxWidth' => 1920, 'maxHeight' => 1073, 'minWidth' => 1920, 'minHeight' => 1073],
            [['country_id'], 'exist', 'skipOnError' => true, 'targetClass' => Country::class, 'targetAttribute' => ['country_id' => 'id']],
            [['region_id'], 'exist', 'skipOnError' => true, 'targetClass' => Region::class, 'targetAttribute' => ['region_id' => 'id']],
            [['season_id'], 'exist', 'skipOnError' => true, 'targetClass' => Season::class, 'targetAttribute' => ['season_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'name' => 'Name',
            'descriptions' => 'Descriptions',
            'venue' => 'Venue',
            'country_id' => 'Country',
            'region_id' => 'Region',
            'currency_id' => 'Currency',
            'address' => 'Address',
            'map' => 'Map',
            'start_date' => 'Start Date',
            'start_time' => 'Start Time',
            'end_date' => 'End Date',
            'end_time' => 'End Time',
            'sales_close' => 'Sales Close',
            'season_id' => 'Season',
            'cover' => 'Cover',
            'status' => 'Status',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
        ];
    }
}