<?php

namespace frontend\controllers;

use common\models\PostHeadliner;
use common\models\PostLineUpList;
use frontend\models\LineUp;
use frontend\models\LineUpList;
use frontend\models\LineUpListSearch;
use Yii;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\Response;
use yii\web\UploadedFile;

/**
 * LineUpListController implements the CRUD actions for LineUpList model.
 */
class LineUpListController extends Controller
{
    /**
     * @inheritDoc
     */
    public function behaviors()
    {
        return array_merge(
            parent::behaviors(),
            [
                'verbs' => [
                    'class' => VerbFilter::className(),
                    'actions' => [
                        'delete' => ['POST'],
                    ],
                ],
            ]
        );
    }

    /**
     * Lists all LineUpList models.
     *
     * @return string
     */
    public function actionIndex()
    {
        $searchModel = new LineUpListSearch();
        $dataProvider = $searchModel->search($this->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single LineUpList model.
     * @param int $id ID
     * @return string
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new LineUpList model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return string|Response
     */
    public function actionCreate()
    {
        $model = new PostLineUpList();

        if ($this->request->isPost) {
            if ($model->load($this->request->post())) {
                Yii::$app->response->format = Response::FORMAT_JSON;

                $model->cover = UploadedFile::getInstance($model, 'cover');
                $imageName = md5($model->cover->baseName.date('d-m-Y-H-i-s').Yii::$app->user->identity->id?? null);
                $path = 'uploads/images/' . $imageName . '.' . $model->cover->extension;
                $uploaded = $model->cover->saveAs($path);

                if($uploaded) {

                    $model->cover = $path;

                    if($model->validate() && $model->save()) {

                        Yii::$app->session->setFlash('success', 'Saved successfully');
                        return $this->redirect(['view', 'id' => $model->id]);
                    }

                }
                Yii::$app->session->setFlash('error', 'Sorry!, Failed to save, please try again');
            }
        } else {
            $model->loadDefaultValues();
        }

        return $this->render('create', [
            'model' => $model,
            'lineUp' => LineUp::find()->where(['status' => 10])->all(),
        ]);
    }

    /**
     * Updates an existing LineUpList model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param int $id ID
     * @return string|Response
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($this->request->isPost && $model->load($this->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id]);
        }

        return $this->render('update', [
            'model' => $model,
            'lineUp' => LineUp::find()->where(['status' => 10])->all(),
        ]);
    }

    /**
     * Deletes an existing LineUpList model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param int $id ID
     * @return Response
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the LineUpList model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param int $id ID
     * @return LineUpList the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = LineUpList::findOne(['id' => $id])) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
}
