<?php

namespace frontend\models;

use Yii;

/**
 * This is the model class for table "events".
 *
 * @property int $id
 * @property string $name
 * @property resource|null $descriptions
 * @property string $venue
 * @property int $country_id
 * @property int $region_id
 * @property int $currency_id
 * @property string $address
 * @property resource $map embedded codes
 * @property string $start_date
 * @property string $start_time
 * @property string $end_date
 * @property string $end_time
 * @property string $sales_close
 * @property int $season_id
 * @property string $cover
 * @property int $status 10 - live, 20 - off
 * @property string $created_at
 * @property string $updated_at
 *
 * @property Country $country
 * @property Currency $currency
 * @property Headliner[] $headliners
 * @property LineUp[] $lineUps
 * @property Partners[] $partners
 * @property Region $region
 * @property Schedule[] $schedules
 * @property Season $season
 * @property Tickets[] $tickets
 */
class Events extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'events';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['name', 'venue', 'country_id', 'region_id', 'address', 'map', 'start_date', 'start_time', 'end_date', 'end_time', 'sales_close', 'season_id'], 'required'],
            [['descriptions', 'map'], 'string'],
            [['country_id', 'region_id', 'currency_id', 'season_id', 'status'], 'integer'],
            [['start_date', 'start_time', 'end_date', 'end_time', 'sales_close', 'created_at', 'updated_at'], 'safe'],
            [['name', 'venue', 'address', 'cover'], 'string', 'max' => 255],
            [['country_id'], 'exist', 'skipOnError' => true, 'targetClass' => Country::class, 'targetAttribute' => ['country_id' => 'id']],
            [['region_id'], 'exist', 'skipOnError' => true, 'targetClass' => Region::class, 'targetAttribute' => ['region_id' => 'id']],
            [['season_id'], 'exist', 'skipOnError' => true, 'targetClass' => Season::class, 'targetAttribute' => ['season_id' => 'id']],
            [['currency_id'], 'exist', 'skipOnError' => true, 'targetClass' => Currency::class, 'targetAttribute' => ['currency_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'name' => 'Name',
            'descriptions' => 'Descriptions',
            'venue' => 'Venue',
            'country_id' => 'Country ID',
            'region_id' => 'Region ID',
            'currency_id' => 'Currency ID',
            'address' => 'Address',
            'map' => 'Map',
            'start_date' => 'Start Date',
            'start_time' => 'Start Time',
            'end_date' => 'End Date',
            'end_time' => 'End Time',
            'sales_close' => 'Sales Close',
            'season_id' => 'Season ID',
            'cover' => 'Cover',
            'status' => 'Status',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
        ];
    }

    /**
     * Gets query for [[Country]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getCountry()
    {
        return $this->hasOne(Country::class, ['id' => 'country_id']);
    }

    /**
     * Gets query for [[Currency]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getCurrency()
    {
        return $this->hasOne(Currency::class, ['id' => 'currency_id']);
    }

    /**
     * Gets query for [[Headliners]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getHeadliners()
    {
        return $this->hasMany(Headliner::class, ['event_id' => 'id']);
    }

    /**
     * Gets query for [[LineUps]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getLineUps()
    {
        return $this->hasMany(LineUp::class, ['event_id' => 'id']);
    }

    /**
     * Gets query for [[Partners]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getPartners()
    {
        return $this->hasMany(Partners::class, ['event_id' => 'id']);
    }

    /**
     * Gets query for [[Region]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getRegion()
    {
        return $this->hasOne(Region::class, ['id' => 'region_id']);
    }

    /**
     * Gets query for [[Schedules]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getSchedules()
    {
        return $this->hasMany(Schedule::class, ['event_id' => 'id']);
    }

    /**
     * Gets query for [[Season]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getSeason()
    {
        return $this->hasOne(Season::class, ['id' => 'season_id']);
    }

    /**
     * Gets query for [[Tickets]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getTickets()
    {
        return $this->hasMany(Tickets::class, ['event_id' => 'id']);
    }
}
