<?php

namespace frontend\models;

use Yii;

/**
 * This is the model class for table "headliner".
 *
 * @property int $id
 * @property int $event_id
 * @property string $name
 * @property string $descriptions
 * @property string $cover
 * @property string|null $video_link
 * @property string $text_on_play_button
 * @property int $status
 * @property string $created_at
 * @property string $updated_at
 *
 * @property Events $event
 * @property HeadlinerAttributes[] $headlinerAttributes
 */
class Headliner extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'headliner';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['event_id', 'name', 'descriptions', 'text_on_play_button'], 'required'],
            [['event_id', 'status'], 'integer'],
            [['created_at', 'updated_at'], 'safe'],
            [['name', 'descriptions', 'cover', 'video_link'], 'string', 'max' => 255],
            [['text_on_play_button'], 'string', 'max' => 50],
            [['event_id'], 'exist', 'skipOnError' => true, 'targetClass' => Events::class, 'targetAttribute' => ['event_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'event_id' => 'Event ID',
            'name' => 'Name',
            'descriptions' => 'Descriptions',
            'cover' => 'Cover',
            'video_link' => 'Video Link',
            'text_on_play_button' => 'Text On Play Button',
            'status' => 'Status',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
        ];
    }

    /**
     * Gets query for [[Event]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getEvent()
    {
        return $this->hasOne(Events::class, ['id' => 'event_id']);
    }

    /**
     * Gets query for [[HeadlinerAttributes]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getHeadlinerAttributes()
    {
        return $this->hasMany(HeadlinerAttributes::class, ['headliner_id' => 'id']);
    }
}
