<?php

namespace frontend\models;

use Yii;

/**
 * This is the model class for table "line_up_list".
 *
 * @property int $id
 * @property int $line_up_id
 * @property string $title
 * @property string|null $sub_title
 * @property string $cover
 * @property int $status
 * @property string $created_at
 * @property string $updated_at
 *
 * @property LineUp $lineUp
 * @property LineUpListSocialMedia[] $lineUpListSocialMedia
 */
class LineUpList extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'line_up_list';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['line_up_id', 'title'], 'required'],
            [['line_up_id', 'status'], 'integer'],
            [['created_at', 'updated_at'], 'safe'],
            [['title', 'sub_title'], 'string', 'max' => 50],
            [['cover'], 'string', 'max' => 255],
            [['line_up_id'], 'exist', 'skipOnError' => true, 'targetClass' => LineUp::class, 'targetAttribute' => ['line_up_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'line_up_id' => 'Line Up ID',
            'title' => 'Title',
            'sub_title' => 'Sub Title',
            'cover' => 'Cover',
            'status' => 'Status',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
        ];
    }

    /**
     * Gets query for [[LineUp]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getLineUp()
    {
        return $this->hasOne(LineUp::class, ['id' => 'line_up_id']);
    }

    /**
     * Gets query for [[LineUpListSocialMedia]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getLineUpListSocialMedia()
    {
        return $this->hasMany(LineUpListSocialMedia::class, ['line_up_list_id' => 'id']);
    }
}
