<?php

namespace frontend\models;

use Yii;

/**
 * This is the model class for table "schedule".
 *
 * @property int $id
 * @property int $event_id
 * @property string $title
 * @property string|null $descriptions
 * @property int $status
 * @property string $created_at
 * @property string $updated_at
 *
 * @property Events $event
 * @property ScheduleDays[] $scheduleDays
 */
class Schedule extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'schedule';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['event_id', 'title'], 'required'],
            [['event_id', 'status'], 'integer'],
            [['descriptions'], 'string'],
            [['created_at', 'updated_at'], 'safe'],
            [['title'], 'string', 'max' => 255],
            [['event_id'], 'exist', 'skipOnError' => true, 'targetClass' => Events::class, 'targetAttribute' => ['event_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'event_id' => 'Event ID',
            'title' => 'Title',
            'descriptions' => 'Descriptions',
            'status' => 'Status',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
        ];
    }

    /**
     * Gets query for [[Event]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getEvent()
    {
        return $this->hasOne(Events::class, ['id' => 'event_id']);
    }

    /**
     * Gets query for [[ScheduleDays]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getScheduleDays()
    {
        return $this->hasMany(ScheduleDays::class, ['schedule_id' => 'id']);
    }
}
