<?php

use kartik\date\DatePicker;
use kartik\datetime\DateTimePicker;
use kartik\editors\Codemirror;
use kartik\editors\Summernote;
use kartik\form\ActiveForm;
use kartik\select2\Select2;
use kartik\time\TimePicker;
use yii\helpers\ArrayHelper;
use yii\helpers\Html;

/** @var yii\web\View $this */
/** @var frontend\models\Events $model */
/** @var yii\widgets\ActiveForm $form */

?>

<div class="events-form">

    <?php $form = ActiveForm::begin(['options' => ['enctype' => 'multipart/form-data', 'method' => 'post']]); ?>

    <div class="row">
        <div class="col-lg-12">
            <?= $form->field($model, 'name')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col-lg-6">
            <?= $form->field($model, 'season_id')->widget(Select2::classname(), [
                'data' => ArrayHelper::map($season, 'id', 'title'),
                'options' => ['placeholder' => 'Select a season ...'],
                'pluginOptions' => [
                    'allowClear' => true
                ],
            ])->label('Season')?>
        </div>
        <div class="col-lg-6">
            <?= $form->field($model, 'venue')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col-lg-12">
            <?= $form->field($model, 'descriptions')->widget(Summernote::class, [
                    'options' => ['placeholder' => 'Edit your blog content here...']
                ]);
            ?>
        </div>
        <div class="col-lg-3">
            <?= $form->field($model, 'country_id')->widget(Select2::classname(), [
                'data' => ArrayHelper::map($country, 'id', 'name'),
                'options' => ['placeholder' => 'Select a country ...'],
                'pluginOptions' => [
                    'allowClear' => true
                ],
            ])->label('Country')?>
        </div>
        <div class="col-lg-3">
            <?= $form->field($model, 'region_id')->widget(Select2::classname(), [
                'data' => ArrayHelper::map($region, 'id', 'name'),
                'options' => ['placeholder' => 'Select a region ...'],
                'pluginOptions' => [
                    'allowClear' => true
                ],
            ])->label('Region')?>
        </div>
        <div class="col-lg-3">
            <?= $form->field($model, 'start_date')->widget(DatePicker::classname(), [
                'options' => ['placeholder' => 'Enter start date ...'],
                'readonly' => true,
                'pluginOptions' => [
                    'autoclose' => true,
                    'format' => 'yyyy-mm-dd'
                ]
            ]);
            ?>
        </div>
        <div class="col-lg-3">
            <?= $form->field($model, 'start_time')->widget(TimePicker::classname(), [
                'options' => ['placeholder' => 'Select start time ...'],
                'readonly' => true,
                'pluginOptions' => [
                    'autoclose' => true,
                    'format' => 'yyyy-mm-dd'
                ]
            ]);
            ?>
        </div>
        <div class="col-lg-3">
            <?= $form->field($model, 'end_date')->widget(DatePicker::classname(), [
                'options' => ['placeholder' => 'Select end date ...'],
                'readonly' => true,
                'pluginOptions' => [
                    'autoclose' => true,
                    'format' => 'yyyy-mm-dd'
                ]
            ]);
            ?>
        </div>
        <div class="col-lg-3">
            <?= $form->field($model, 'end_time')->widget(TimePicker::classname(), [
                'options' => ['placeholder' => 'Select start time ...'],
                'readonly' => true,
                'pluginOptions' => [
                    'autoclose' => true,
                    'format' => 'yyyy-mm-dd'
                ]
            ]);
            ?>
        </div>
        <div class="col-lg-3">
            <?= $form->field($model, 'sales_close')->widget(DateTimePicker::classname(), [
                'options' => ['placeholder' => 'Select sales close time ...'],
                'readonly' => true,
                'pluginOptions' => [
                    'autoclose' => true,
                ]
            ]);
            ?>
        </div>
        <div class="col-lg-3">
            <?= $form->field($model, 'status')->dropDownList(
                ArrayHelper::map(
                    [
                        ['id' => 10, 'name' => 'ACTIVE'],
                        ['id' => 20, 'name' => 'INACTIVE']
                    ],
                    'id',
                    'name'
                )
            ) ?>
        </div>
        <div class="col-lg-4">
            <?= $form->field($model, 'currency_id')->widget(Select2::classname(), [
                'data' => ArrayHelper::map($currency, 'id', 'name'),
                'options' => ['placeholder' => 'Select a currency ...'],
                'pluginOptions' => [
                    'allowClear' => true
                ],
            ])->label('Currency')?>
        </div>

        <div class="col-lg-4">
            <?= $form->field($model, 'address')->textInput(['maxlength' => true]) ?>
        </div>

        <?php if(!$model->id){?>
        <div class="col-lg-4">

            <div class="mb-3">
                <label for="formFile" class="form-label">Choose Cover</label>
                <?= $form->field($model, 'cover')->fileInput(['multiple' => false, 'accept' => 'image/*'])->label(false) ?>
            </div>
        </div>
        <?php } ?>
        <div class="col-lg-12">
            <?= $form->field($model, 'map')->textarea(['rows' => 4]) ?>
        </div>
    </div>
    <div class="form-group">
        <?= Html::submitButton('Save', ['class' => 'btn btn-sm btn-success']) ?>
    </div>

    <?php ActiveForm::end(); ?>

</div>
