<?php

/** @var View $this */
/** @var string $content */


use dominus77\sweetalert2\Alert;
use frontend\assets\AppAsset;
use yii\bootstrap5\Breadcrumbs;
use yii\bootstrap5\Nav;
use yii\bootstrap5\NavBar;
use yii\helpers\Html;
use yii\web\View;

AppAsset::register($this);
?>
<?php $this->beginPage() ?>
<!DOCTYPE html>
<html lang="<?= Yii::$app->language ?>" class="h-100">
<head>
    <meta charset="<?= Yii::$app->charset ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <?php $this->registerCsrfMetaTags() ?>
    <title><?= Html::encode($this->title) ?></title>
    <?php $this->head() ?>
</head>
<body class="d-flex flex-column h-100">
<?php $this->beginBody() ?>

<header>
    <?php
    NavBar::begin([
        'brandLabel' => Html::img(Yii::$app->request->baseUrl . '/themes/site/assets/images/maasai.png', ['height' => '50px']),
        'brandUrl' => Yii::$app->homeUrl,
        'options' => [
            'class' => 'navbar navbar-expand-md navbar-dark bg-dark fixed-top',
        ],
    ]);

    if (Yii::$app->user->isGuest) {
        $menuItems[] = ['label' => 'Signup', 'url' => ['/site/signup']];
    }else{

        $menuItems = [
            [
                'label' => 'Events',
                'items' => [
                    ['label' => 'All', 'url' => ['/events/index']],
                    ['label' => 'Create', 'url' => ['/events/create']],
                    // Add more dropdown items as needed
                ],
            ],
            ['label' => 'Season', 'url' => ['/season/index']],
            ['label' => 'Tickets', 'url' => ['/tickets/index']],
            [
                'label' => 'Setup Page',
                'items' => [
                    ['label' => 'Registration Form', 'url' => ['/registration-form/index']],
                    ['label' => 'Headliner', 'url' => ['/headliner/index']],
                    ['label' => 'Attributes', 'url' => ['/headliner-attributes/index']],
                    ['label' => 'Line Up', 'url' => ['/line-up/index']],
                    ['label' => 'Line Up List', 'url' => ['/line-up-list/index']],
                    ['label' => 'Schedule', 'url' => ['/schedule/index']],
                    ['label' => 'Schedule Days', 'url' => ['/schedule-days/index']],
                    ['label' => 'Schedule Days List', 'url' => ['/schedule-days-list/index']],
                    ['label' => 'Amazing Tanzania', 'url' => ['/gallery/index']],
                    // Add more dropdown items as needed
                ],
            ],
        ];
    }

    echo Nav::widget([
        'options' => ['class' => 'navbar-nav me-auto mb-2 mb-md-0'],
        'items' => $menuItems,
    ]);
    if (Yii::$app->user->isGuest) {
        echo Html::tag('div',Html::a('Login',['/site/login'],['class' => ['btn btn-link login text-decoration-none']]),['class' => ['d-flex']]);
    } else {
        echo Html::beginForm(['/site/logout'], 'post', ['class' => 'd-flex']);
        echo Html::beginTag('ul', ['class' => 'navbar-nav']);
        echo Html::beginTag('li', ['class' => 'nav-item dropdown']);
        echo Html::button(
            'Hello  ' . Yii::$app->user->identity->names?? '',
            ['class' => 'btn btn-dark dropdown-toggle', 'id' => 'logoutDropdown', 'data-bs-toggle' => 'dropdown', 'aria-expanded' => 'false']
        );
        echo Html::beginTag('ul', ['class' => 'dropdown-menu dropdown-menu-dark']);

        $menuItemsProfile = [
            ['label' => 'My Profile', 'url' => ['/user/profile'], 'icon' => 'user'],
            ['label' => 'Change Email', 'url' => ['/user/email'], 'icon' => 'envelope'],
            ['label' => 'Change Password', 'url' => ['/user/password'], 'icon' => 'lock'],
        ];

        foreach ($menuItemsProfile as $item) {
            if (isset($item['url'])) {
                echo Html::tag('li', Html::a($item['label'], $item['url'], ['class' => 'dropdown-item']));
            } else {
                echo Html::tag('li', Html::a($item['label'], '#', ['class' => 'dropdown-item']));
            }
        }
        echo Html::tag('li', Html::submitButton('Logout', ['class' => 'dropdown-item', 'name' => 'logout-button']));
        echo Html::endTag('ul');
        echo Html::endTag('li');
        echo Html::endTag('ul');
        echo Html::endForm();
    }
    NavBar::end();
    ?>
</header>

<main role="main" class="flex-shrink-0">
    <div class="container mt-5">
        <?= Breadcrumbs::widget([
            'links' => isset($this->params['breadcrumbs']) ? $this->params['breadcrumbs'] : [],
        ]) ?>
        <?php Alert::widget(['useSessionFlash' => true]); ?>
        <?= $content ?>
    </div>
</main>

<footer class="footer mt-auto py-3 text-muted">
    <div class="container">
        <p class="float-start">&copy; <?= Html::encode(Yii::$app->name) ?> <?= date('Y') ?></p>
        <p class="float-end"><?= Yii::powered() ?></p>
    </div>
</footer>

<?php $this->endBody() ?>
</body>
</html>
<?php $this->endPage();
