<?php

use frontend\models\LineUpList;
use yii\helpers\Html;
use yii\helpers\Url;
use yii\grid\ActionColumn;
use yii\grid\GridView;
use yii\widgets\Pjax;
/** @var yii\web\View $this */
/** @var frontend\models\LineUpListSearch $searchModel */
/** @var yii\data\ActiveDataProvider $dataProvider */

$this->title = 'Line Up Lists';
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="line-up-list-index">

    <p>
        <?= Html::a('Create Line Up List', ['create'], ['class' => 'btn btn-sm btn-success']) ?>
    </p>

    <?php Pjax::begin(); ?>

    <?= GridView::widget([
        'dataProvider' => $dataProvider,
        'filterModel' => $searchModel,
        'tableOptions' => ['class' => 'table table-striped nowrap table-striped align-middle table-sm table-hover text-nowrap'],
        'columns' => [
            ['class' => 'yii\grid\SerialColumn'],

            [
                'label' => 'cover',
                'format' => 'raw',
                'value' => function ($table) {
                    return Html::img(Yii::getAlias('@web') . '/'.$table->cover, ['alt' => 'Headliner Image', 'height' => '60']);
                },
            ],
            [
                'attribute' => 'line_up_id',
                'format' => 'html', //  <text>, <html>, <row>
                'label' => 'Line Up',
                'value' => function ($table) {
                    return $table->lineUp->title?? '';
                }
            ],
            [
                'attribute' => 'title',
                'format' => 'html', //  <text>, <html>, <row>
                'label' => 'Name',
                'value' => function ($table) {
                    return $table->title?? '';
                }
            ],
            [
                'attribute' => 'sub_title',
                'format' => 'html', //  <text>, <html>, <row>
                'label' => 'Genre',
                'value' => function ($table) {
                    return $table->sub_title?? '';
                }
            ],
            [
                'attribute' => 'status',
                'filter'=>array("10"=>"ACTIVE","20"=>"INACTIVE"),
                'label' => 'Status',
                'format' => 'html', //  <text>, <html>, <row>
                'value' => function($table) {
                    return (isset($table->status) && ($table->status == 10))? '<span class="badge bg-success">ACTIVE</span>' : '<span class="badge bg-danger">INACTIVE</span>' ;
                }
            ],
            'created_at:datetime',
            //'updated_at',
            [
                'class' => ActionColumn::className(),
                'urlCreator' => function ($action, LineUpList $model, $key, $index, $column) {
                    return Url::toRoute([$action, 'id' => $model->id]);
                 }
            ],
        ],
    ]); ?>

    <?php Pjax::end(); ?>

</div>
