<?php

use frontend\models\Schedule;
use yii\helpers\Html;
use yii\helpers\Url;
use yii\grid\ActionColumn;
use yii\grid\GridView;
use yii\widgets\Pjax;
/** @var yii\web\View $this */
/** @var frontend\models\ScheduleSearch $searchModel */
/** @var yii\data\ActiveDataProvider $dataProvider */

$this->title = 'Schedules';
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="schedule-index">

    <p>
        <?= Html::a('Create Schedule', ['create'], ['class' => 'btn btn-sm btn-success']) ?>
    </p>

    <?php Pjax::begin(); ?>

    <?= GridView::widget([
        'dataProvider' => $dataProvider,
        'filterModel' => $searchModel,
        'tableOptions' => ['class' => 'table table-striped nowrap table-striped align-middle table-sm table-hover text-nowrap'],
        'columns' => [
            ['class' => 'yii\grid\SerialColumn'],

            [
                'attribute' => 'event_id',
                'format' => 'html', //  <text>, <html>, <row>
                'value' => function ($table) {
                    return $table->event->name?? '';
                }
            ],
            'title',
            [
                'attribute' => 'descriptions',
                'format' => 'html', //  <text>, <html>, <row>
                'value' => function ($table) {
                    return nl2br(Html::encode(substr($table->descriptions, 0, 50))).' ...';
                }
            ],
            [
                'attribute' => 'status',
                'filter'=>array("10"=>"ACTIVE","20"=>"INACTIVE"),
                'label' => 'Status',
                'format' => 'html', //  <text>, <html>, <row>
                'value' => function($table) {
                    return (isset($table->status) && ($table->status == 10))? '<span class="badge bg-success">ACTIVE</span>' : '<span class="badge bg-danger">INACTIVE</span>' ;
                }
            ],
            'created_at:datetime',
            [
                'class' => ActionColumn::className(),
                'urlCreator' => function ($action, Schedule $model, $key, $index, $column) {
                    return Url::toRoute([$action, 'id' => $model->id]);
                 }
            ],
        ],
    ]); ?>

    <?php Pjax::end(); ?>

</div>
