<?php

use frontend\models\Tickets;
use yii\helpers\Html;
use yii\helpers\Url;
use yii\grid\ActionColumn;
use yii\grid\GridView;
use yii\widgets\Pjax;
/** @var yii\web\View $this */
/** @var frontend\models\TicketsSearch $searchModel */
/** @var yii\data\ActiveDataProvider $dataProvider */

$this->title = 'Tickets';
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="tickets-index">

    <p>
        <?= Html::a('Create Tickets', ['create'], ['class' => 'btn btn-sm btn-success']) ?>
    </p>

    <?php Pjax::begin(); ?>

    <?= GridView::widget([
        'dataProvider' => $dataProvider,
        'filterModel' => $searchModel,
        'tableOptions' => ['class' => 'table table-striped table-sm table-hover text-nowrap'],
        'columns' => [
            ['class' => 'yii\grid\SerialColumn'],

            'name',
            'event.name',
            'description',
            [
                'attribute' => 'price',
                'format' => 'html', //  <text>, <html>, <row>
                'contentOptions' => ['style' => 'text-align:right;'],  // Optional: align content to the right
                'value' => function($table) {
                    return $table->event->currency->symbol. ' '.$table->price ;
                }
            ],
            [
                'attribute' => 'status',
                'filter'=>array("10"=>"ACTIVE","20"=>"INACTIVE"),
                'label' => 'Status',
                'format' => 'html', //  <text>, <html>, <row>
                'value' => function($table) {
                    return (isset($table->status) && ($table->status == 10))? '<span class="badge bg-success">ACTIVE</span>' : '<span class="badge bg-danger">INACTIVE</span>' ;
                }
            ],
            'created_at:date',
            [
                'class' => ActionColumn::className(),
                'urlCreator' => function ($action, Tickets $model, $key, $index, $column) {
                    return Url::toRoute([$action, 'id' => $model->id]);
                 }
            ],
        ],
    ]); ?>

    <?php Pjax::end(); ?>

</div>
